@@ -1,6 +1,8 @@
-#' @title Calculate standard errors for estimated CIFs and treatment effects
+#' @title 
+#' Calculate standard errors for estimated CIFs and treatment effects
 #'
-#' @description This function calculates the standard error for the estimated potential cumulative incidence function
+#' @description 
+#' This function calculates the standard error for the estimated potential cumulative incidence function
 #' and treatment effect. Two methods to calculate the standard error are considered: the asymptotic standard error
 #' based on the explicit formula and bootstrapping.
 #'
@@ -56,11 +58,11 @@ surv.boot <- function(fit,nboot=0,seed=NULL){
     for(b in 1:nboot){
       subset = sample(1:N,replace=TRUE)
       if (fit$dtype=='cmprsk'){
-      fitb = surv.tteICE(fit$A,fit$Time,fit$cstatus,fit$strategy,fit$cov1,fit$method,
-                      fit$weights,na.rm=FALSE,nboot=-1)
+        fitb = surv.tteICE(fit$A,fit$Time,fit$cstatus,fit$strategy,fit$cov1,fit$method,
+                           fit$weights,subset=subset,na.rm=FALSE,nboot=-1)
       } else {
-      fitb = scr.tteICE(fit$A,fit$Time,fit$status,fit$Time_int,fit$status_int,fit$strategy,fit$cov1,fit$method,
-                        fit$weights,na.rm=FALSE,nboot=-1)
+        fitb = scr.tteICE(fit$A,fit$Time,fit$status,fit$Time_int,fit$status_int,fit$strategy,fit$cov1,fit$method,
+                          fit$weights,subset=subset,na.rm=FALSE,nboot=-1)
       }
       cifb1 = .matchy(fitb$cif1,fitb$time1,tt)
       cifb0 = .matchy(fitb$cif0,fitb$time0,tt)
@@ -74,4 +76,4 @@ surv.boot <- function(fit,nboot=0,seed=NULL){
   }
   return(list(time=tt,cif1=cif1,cif0=cif0,ate=ate,se1=se1,se0=se0,se=se,p.val=p.val,
               strategy=fit$strategy,method=fit$method,dtype=fit$dtype))
-}
+}
\ No newline at end of file
